@@ -1,20 +1,20 @@
 from .node import Node
 from ..utils.centernet.mapping import mapping as centernet_mapping
 
-def get_det_config(dataset):
+def get_det_config(project):
 
-    client = dataset.client
-    dataset_name = dataset.name
-    dataset_owner = dataset.owner['username']   
-    categories = dataset.categories
+    client = project.client
+    project_name = project.name
+    project_owner = project.owner['username']   
+    categories = project.categories
 
     cfg = Node(
         dict(
             client = client,
 
-            dataset_info = dict(
-                name = dataset_name,
-                owner = dataset_owner,
+            project_info = dict(
+                name = project_name,
+                owner = project_owner,
                 categories = categories
             ),
 
@@ -32,8 +32,8 @@ def get_det_config(dataset):
                 name = 'detection',
                 params = Node(dict(
                     client = client,
-                    name = dataset_name,
-                    owner = dataset_owner,
+                    name = project_name,
+                    owner = project_owner,
                     labeled_only = True,
                     approved_only = False,
                     split = True,
@@ -50,8 +50,8 @@ def get_det_config(dataset):
                 name = 'detection',
                 params = Node(dict(
                     client = client,
-                    name = dataset_name,
-                    owner = dataset_owner,
+                    name = project_name,
+                    owner = project_owner,
                     labeled_only = True,
                     approved_only = False,
                     split = True,
